@@ -1,4 +1,4 @@
-from .cloud_storage import connect, change_namespace, download_file
+from .cloud_storage import connect, change_namespace, download_file, read_remote_csv_pandas
 from .config import get_auth_token, save_auth_token, check_auth, make_auth, check_config, make_config, load_config, check_ssh_connection, get_token
 from .remote_exec import remote_exec
 from . import vars
@@ -7,7 +7,7 @@ from tempfile import gettempdir
 from os import mkdir
 
 # CloudComputing version
-__version__ = "0.2.0"
+__version__ = "0.2.2"
 # Author (GitHub username)
 __author__ = "mp1994"
 
